==> jc-project-operation-domain-0.0.116-sources.jar: com/xforceplus/ultraman/app/jcprojectoperation/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.jcprojectoperation.metadata;

/**
 *
 * @author ultraman
 * @since 2024-03-18
 */

public class PageMeta {
    public interface BillMonitor {
        static String code() {
            return "billMonitor";
        }
        static String name() {
            return "业务单状态异常";
        }
    }
    public interface SellerInvoiceMonitor {
        static String code() {
            return "sellerInvoiceMonitor";
        }
        static String name() {
            return "销项发票异常";
        }
    }
    public interface RedMonitor {
        static String code() {
            return "redMonitor";
        }
        static String name() {
            return "红字信息状态异常";
        }
    }
    public interface PreMonitor {
        static String code() {
            return "preMonitor";
        }
        static String name() {
            return "预制发票状态异常";
        }
    }
    public interface Leqimanagement {
        static String code() {
            return "leqimanagement";
        }
        static String name() {
            return "乐企管理页面";
        }
    }
    public interface Redletter {
        static String code() {
            return "redletter";
        }
        static String name() {
            return "红字确认单";
        }
    }
    public interface Manaualinvoicing {
        static String code() {
            return "manaualinvoicing";
        }
        static String name() {
            return "手工开票";
        }
    }
    public interface Invoicelist {
        static String code() {
            return "invoicelist";
        }
        static String name() {
            return "发票池";
        }
    }
}

==> jc-project-operation-domain-0.0.224-sources.jar: com/xforceplus/ultraman/app/jcprojectoperation/metadata/PageMeta.java <==
package com.xforceplus.ultraman.app.jcprojectoperation.metadata;

/**
 *
 * @author ultraman
 * @since 2024-06-03
 */

public class PageMeta {
    public interface App {
        static String code() {
            return "app";
        }
        static String name() {
            return "应用";
        }
    }
    public interface Invoicelist {
        static String code() {
            return "invoicelist";
        }
        static String name() {
            return "发票池";
        }
    }
    public interface BillMonitor {
        static String code() {
            return "billMonitor";
        }
        static String name() {
            return "业务单状态异常";
        }
    }
    public interface RedMonitor {
        static String code() {
            return "redMonitor";
        }
        static String name() {
            return "红字信息状态异常";
        }
    }
    public interface Leqimanagement {
        static String code() {
            return "leqimanagement";
        }
        static String name() {
            return "乐企管理页面";
        }
    }
    public interface Manaualinvoicing {
        static String code() {
            return "manaualinvoicing";
        }
        static String name() {
            return "手工开票";
        }
    }
    public interface Redletter {
        static String code() {
            return "redletter";
        }
        static String name() {
            return "红字确认单";
        }
    }
    public interface SpecialInvoiceType {
        static String code() {
            return "specialInvoiceType";
        }
        static String name() {
            return "底账新增发票类型";
        }
    }
    public interface SellerInvoiceMonitor {
        static String code() {
            return "sellerInvoiceMonitor";
        }
        static String name() {
            return "销项发票异常";
        }
    }
    public interface PreMonitor {
        static String code() {
            return "preMonitor";
        }
        static String name() {
            return "预制发票状态异常";
        }
    }
}
